/*
 * Copyright 2013 Mark Slater
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
 *
 * 	http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
 */

package net.sourceforge.xazzle.xhtml;

import org.sourceforge.writexml.Attribute;
import org.sourceforge.writexml.Attributes;

import static java.util.Arrays.asList;
import static net.sourceforge.xazzle.xhtml.IterableUtils.cons;
import static org.sourceforge.writexml.Attributes.attributes;
import static org.sourceforge.writexml.TagName.tagName;

public final class FieldSetTag<T extends MayContainFormTag>
        extends StandardXhtmlTag<FieldSetTag<T>, XhtmlTag>
        implements XhtmlTag, BodyElement<T, TagScope.Block> {

    private FieldSetTag(final Attributes attributes, final Iterable<? extends XhtmlTag> children) {
        super(tagName("fieldset"), attributes, children);
    }

    static <T extends MayContainFormTag> FieldSetTag<T> fieldSetTag(final LegendTag legendTag, final BlockTagContents<? extends T>... children) {
        return fieldSetTag(legendTag, asList(children));
    }

    static <T extends MayContainFormTag> FieldSetTag<T> fieldSetTag(final LegendTag legendTag, final Iterable<? extends BlockTagContents<? extends T>> children) {
        return new FieldSetTag<>(attributes(), cons(legendTag, children));
    }

    FieldSetTag<T> makeANewOne(final Attribute attribute) {
        return new FieldSetTag<>(attributes.append(attribute), children);
    }

}
