/*
 * Copyright 2013 Mark Slater
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
 *
 * 	http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
 */

package net.sourceforge.xazzle.xhtml;

import org.sourceforge.writexml.Attribute;
import org.sourceforge.writexml.Attributes;
import org.sourceforge.writexml.TagName;

import java.util.Collections;

import static org.sourceforge.writexml.Attribute.attribute;
import static org.sourceforge.writexml.Attributes.attributes;
import static org.sourceforge.writexml.TagName.tagName;

public final class InputTag extends SelectableFormElementTag<InputTag> {

    static InputTag inputTag() {
        return new InputTag(tagName("input"), attributes(), Collections.<XhtmlTag>emptyList());
    }

    private InputTag(final TagName img, final Attributes attributes, final Iterable<? extends XhtmlTag> children) {
        super(img, attributes, children);
    }

    @Override
    InputTag makeANewOne(final Attribute attribute) {
        return new InputTag(tagName, attributes.append(attribute), children);
    }

    public InputTag withAccept(final Accept accept) {
        return makeANewOne(attribute("accept", accept, NAMESPACE));
    }

    public InputTag withClientSideMap(final Id someMap) {
        return makeANewOne(attribute("usemap", someMap.asReference(), NAMESPACE));
    }

    public InputTag withAlternateText(final AlternateText alternateText) {
        return makeANewOne(attribute("alt", alternateText, NAMESPACE));
    }

    public InputTag withSize(final Size size) {
        return makeANewOne(attribute("size", size, NAMESPACE));
    }

    public InputTag checked() {
        return makeANewOne(attribute("checked", new Checked(), NAMESPACE));
    }

    public InputTag withType(final InputType inputType) {
        return makeANewOne(attribute("type", inputType, NAMESPACE));
    }

    public InputTag withImageSource(final ImageSource imageSource) {
        return makeANewOne(attribute("src", imageSource, NAMESPACE));
    }

    public InputTag withValue(final Value value) {
        return makeANewOne(attribute("value", value, NAMESPACE));
    }

    public InputTag withMaximumLength(final MaximumLength maximumLength) {
        return makeANewOne(attribute("maxlength", maximumLength, NAMESPACE));
    }

}
