/*
 * Copyright 2013 Mark Slater
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
 *
 * 	http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
 */

package net.sourceforge.xazzle.xhtml;

import org.sourceforge.writexml.Attribute;
import org.sourceforge.writexml.Attributes;
import org.sourceforge.writexml.TagName;

import static java.util.Arrays.asList;
import static net.sourceforge.xazzle.xhtml.CollectionUtils.newList;
import static net.sourceforge.xazzle.xhtml.IterableUtils.cons;
import static org.sourceforge.writexml.Attribute.attribute;
import static org.sourceforge.writexml.Attributes.attributes;
import static org.sourceforge.writexml.TagName.tagName;

public final class OptionGroupTag extends SelectTagElement<OptionGroupTag> {
    static OptionGroupTag optionGroupTag(final Label label, final OptionTag optionTag, final OptionTag... optionTags) {
        final Iterable<OptionTag> children = cons(optionTag, asList(optionTags));
        return optionGroupTag(label, children);
    }

    static OptionGroupTag optionGroupTag(final Label label, final OptionTag optionTag, final Iterable<OptionTag> optionTags) {
        return optionGroupTag(label, cons(optionTag, newList(optionTags)));
    }

    private static OptionGroupTag optionGroupTag(final Label label, final Iterable<OptionTag> children) {
        return new OptionGroupTag(tagName("optgroup"), attributes(attribute("label", label, NAMESPACE)), children);
    }

    private OptionGroupTag(final TagName tagName, final Attributes attributes, final Iterable<? extends XhtmlTag> children) {
        super(tagName, attributes, children);
    }

    @Override
    OptionGroupTag makeANewOne(final Attribute attribute) {
        return new OptionGroupTag(tagName, attributes.append(attribute), children);
    }

}
